============
Installation
============

PyPI
====

The Python package is available on the `Python Package Index`_ (PyPI) as
``fedora-messaging``::

    $ pip install --user fedora-messaging

It is, of course, recommended that you install it in a Python virtual
environment.

.. _Python Package Index: https://pypi.org/project/fedora-messaging/

Fedora
======

The library is available in Fedora 29 and greater as ``fedora-messaging``::

   $ sudo dnf install fedora-messaging
